==> gorilla-notebook-0.4.10.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.bitbucket.js <==
goog.provide('pinkgorilla.storage.direct.bitbucket');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.bitbucket');
(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.bitbucket","/tmp/form-init9210512555929219670.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["bitbucket.load"], null);
}),null)),null,-552562215);

return ["https://bitbucket.org/api/1.0/repositories/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.user),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.repo),"/raw/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.revision),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.path)].join('');
}));

(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,content){
var self__$1 = this;
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.bitbucket.js.map

==> gorilla-notebook-0.4.11.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.bitbucket.js <==
goog.provide('pinkgorilla.storage.direct.bitbucket');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.bitbucket');
(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.bitbucket","/tmp/form-init1011153544949464259.clj",11,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["bitbucket.load"], null);
}),null)),null,496206845);

return ["https://bitbucket.org/api/1.0/repositories/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.user),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.repo),"/raw/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.revision),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.path)].join('');
}));

(pinkgorilla.storage.bitbucket.StorageBitbucket.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,content){
var self__$1 = this;
return content;
}));

//# sourceMappingURL=pinkgorilla.storage.direct.bitbucket.js.map
